import { Text, TouchableOpacity, StyleSheet, View, TouchableWithoutFeedback, Platform } from 'react-native';
import { SvgProps } from 'react-native-svg';

import { NAVIGATION_PAGES } from '../../types';

import MapIcon from '../../../assets/icons/bottom-navigation/map.svg';
import TravellersIcon from '../../../assets/icons/bottom-navigation/travellers.svg';
import TravelsIcon from '../../../assets/icons/bottom-navigation/travels.svg';
import ProfileIcon from '../../../assets/icons/bottom-navigation/profile.svg';
import { useState } from 'react';

const getTabIcon = (routeName: string) => {
  switch (routeName) {
    case NAVIGATION_PAGES.MAP_TAB:
      return MapIcon;
    case NAVIGATION_PAGES.TRAVELLERS_TAB:
      return TravellersIcon;
    case NAVIGATION_PAGES.TRAVELS_TAB:
      return TravelsIcon;
    case NAVIGATION_PAGES.PROFILE_TAB:
      return ProfileIcon;
    default:
      return null;
  }
};

const TabBarButton = ({ label, onPress, focused }: { label: string, onPress: () => void, focused: boolean }) => {
  const [isPressed, setIsPressed] = useState(false);

  const handlePressIn = () => {
    setIsPressed(true);
  };

  const handlePressOut = () => {
    setIsPressed(false);
  };

  const styles = StyleSheet.create({
    buttonStyle: {
      flex: 1,
      alignItems: 'center',
      justifyContent: 'center',
      overflow: 'hidden',
    },
    labelStyle: {
      color: focused ? '#0F3F4F' : '#C8C8C8',
      marginTop: 4,
      fontSize: 10,
      // lineHeight: 12,
      // ...Platform.select({
      //   android: {
      //     marginBottom: 6,
      //   },
      // }),
    },
  });

  const IconComponent: React.FC<SvgProps> | null = getTabIcon(label);

  let currentColor = focused ? '#0F3F4F' : '#C8C8C8';


  return (
    <TouchableWithoutFeedback onPress={onPress} onPressIn={handlePressIn} onPressOut={handlePressOut} style={{}}>
      <View style={styles.buttonStyle}>
        {IconComponent && <IconComponent width={24} height={24} fill={focused ? '#0F3F4F' : '#C8C8C8'} />}
        <Text style={styles.labelStyle}>{label}</Text>
      </View>
    </TouchableWithoutFeedback>
  );
};

export default TabBarButton;
